annotate Package
================

:mod:`annotate` Package
-----------------------

.. automodule:: numba.annotate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`annotate` Module
----------------------

.. automodule:: numba.annotate.annotate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`annotators` Module
------------------------

.. automodule:: numba.annotate.annotators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`htmlrender` Module
------------------------

.. automodule:: numba.annotate.htmlrender
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ir_capture` Module
------------------------

.. automodule:: numba.annotate.ir_capture
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`step` Module
------------------

.. automodule:: numba.annotate.step
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`textrender` Module
------------------------

.. automodule:: numba.annotate.textrender
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.annotate.tests

